@@ -1,10 +1,10 @@
 /*
- * Logswan 2.1.0
+ * Logswan 2.1.1
  * Copyright (c) 2015-2019, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2019-09-27
+ * Last Updated: 2019-10-28
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
@@ -31,7 +31,7 @@
 #include <string.h>
 #include <time.h>
 
-#if defined(__linux__)
+#ifdef HAVE_SECCOMP
 #include <sys/prctl.h>
 #include <sys/syscall.h>
 #include <linux/audit.h>
@@ -80,11 +80,13 @@ int8_t getoptFlag;
 
 struct HLL uniqueIPv4, uniqueIPv6;
 char *intputFile;
+char *db = NULL;
 
 void
 displayUsage() {
 	printf("USAGE: logswan [options] inputfile\n\n" \
 	    "Options are:\n\n" \
+	    "	-d Specify path to a GeoIP database\n" \
 	    "	-g Enable GeoIP lookups\n" \
 	    "	-h Display usage\n" \
 	    "	-v Display version\n");
@@ -99,16 +101,27 @@ main(int argc, char *argv[]) {
 		err(EXIT_FAILURE, "pledge");
 	}
 
-#if defined(__linux__)
-	prctl(PR_SET_NO_NEW_PRIVS, 1, 0, 0, 0);
-	prctl(PR_SET_SECCOMP, SECCOMP_MODE_FILTER, &logswan);
+#ifdef HAVE_SECCOMP
+	if (prctl(PR_SET_NO_NEW_PRIVS, 1, 0, 0, 0)) {
+		perror("Can't initialize seccomp");
+		return EXIT_FAILURE;
+	}
+
+	if (prctl(PR_SET_SECCOMP, SECCOMP_MODE_FILTER, &logswan)) {
+		perror("Can't load seccomp filter");
+		return EXIT_FAILURE;
+	}
 #endif
 
 	hll_init(&uniqueIPv4, HLL_BITS);
 	hll_init(&uniqueIPv6, HLL_BITS);
 
-	while ((getoptFlag = getopt(argc, argv, "ghv")) != -1) {
+	while ((getoptFlag = getopt(argc, argv, "d:ghv")) != -1) {
 		switch (getoptFlag) {
+		case 'd':
+			db = optarg;
+			break;
+
 		case 'g':
 			geoip = true;
 			break;
@@ -138,8 +151,10 @@ main(int argc, char *argv[]) {
 
 	/* Initializing GeoIP */
 	if (geoip) {
-		if (MMDB_open(GEOIP2DIR "GeoLite2-Country.mmdb",
-		    MMDB_MODE_MMAP, &geoip2) != MMDB_SUCCESS) {
+		if (!db)
+			db = GEOIP2DIR GEOIP2DB;
+
+		if (MMDB_open(db, MMDB_MODE_MMAP, &geoip2) != MMDB_SUCCESS) {
 			perror("Can't open database");
 			return EXIT_FAILURE;
 		}
